===========================
 Extension Manager Classes
===========================

DriverManager
=============

.. autoclass:: stevedore.driver.DriverManager

HookManager
===========

.. autoclass:: stevedore.hook.HookManager

NamedExtensionManager
=====================

.. autoclass:: stevedore.named.NamedExtensionManager

EnabledExtensionManager
=======================

.. autoclass:: stevedore.enabled.EnabledExtensionManager

DispatchExtensionManager
========================

.. autoclass:: stevedore.dispatch.DispatchExtensionManager

NameDispatchExtensionManager
============================

.. autoclass:: stevedore.dispatch.NameDispatchExtensionManager

ExtensionManager
================

.. autoclass:: stevedore.extension.ExtensionManager

Extension
=========

.. autoclass:: stevedore.extension.Extension
   :members:
   :show-inheritance:
   :no-special-members:

TestExtensionManager
====================

.. autoclass:: stevedore.tests.manager.TestExtensionManager
